@@ -8,39 +8,20 @@
 extern "C" {
 #endif
 
-#include "lilv_config.h" // IWYU pragma: keep
+#include "lilv_config.h"
 
-#include "lilv/lilv.h"
-#include "lv2/core/lv2.h"
-#include "serd/serd.h"
-#include "sord/sord.h"
-#include "zix/tree.h"
+#include <lilv/lilv.h>
+#include <lv2/core/lv2.h>
+#include <serd/serd.h>
+#include <sord/sord.h>
+#include <zix/tree.h>
 
 #include <stdbool.h>
 #include <stdint.h>
 #include <stdio.h>
 
-#ifdef _WIN32
-#  include <direct.h>
-#  include <windows.h>
-#  define dlopen(path, flags) LoadLibrary(path)
-#  define dlclose(lib) FreeLibrary((HMODULE)lib)
-#  ifdef _MSC_VER
-#    ifndef snprintf
-#      define snprintf _snprintf
-#    endif
-#  endif
-static inline const char*
-dlerror(void)
-{
-  return "Unknown error";
-}
-#else
-#  include <dlfcn.h>
-#endif
-
 #ifdef LILV_DYN_MANIFEST
-#  include "lv2/dynmanifest/dynmanifest.h"
+#  include <lv2/dynmanifest/dynmanifest.h>
 #endif
 
 /*
@@ -391,9 +372,6 @@ lilv_strdup(const char* str);
 char*
 lilv_get_lang(void);
 
-char*
-lilv_expand(const char* path);
-
 char*
 lilv_get_latest_copy(const char* path, const char* copy_path);
 
@@ -402,21 +380,6 @@ lilv_find_free_path(const char* in_path,
                     bool (*exists)(const char*, const void*),
                     const void* user_data);
 
-typedef void (*LilvVoidFunc)(void);
-
-/** dlsym wrapper to return a function pointer (without annoying warning) */
-static inline LilvVoidFunc
-lilv_dlfunc(void* handle, const char* symbol)
-{
-#ifdef _WIN32
-  return (LilvVoidFunc)GetProcAddress((HMODULE)handle, symbol);
-#else
-  typedef LilvVoidFunc (*VoidFuncGetter)(void*, const char*);
-  VoidFuncGetter dlfunc = (VoidFuncGetter)dlsym;
-  return dlfunc(handle, symbol);
-#endif
-}
-
 #ifdef LILV_DYN_MANIFEST
 static const LV2_Feature* const dman_features = {NULL};
 
