@@ -3,18 +3,18 @@
 
 #include "lilv_internal.h"
 
-#include "lilv/lilv.h"
-#include "serd/serd.h"
-#include "sord/sord.h"
-#include "zix/tree.h"
-
-#include "lv2/core/lv2.h"
-#include "lv2/ui/ui.h"
-
 #ifdef LILV_DYN_MANIFEST
-#  include "lv2/dynmanifest/dynmanifest.h"
+#  include "dylib.h"
+#  include <lv2/dynmanifest/dynmanifest.h>
 #endif
 
+#include <lilv/lilv.h>
+#include <lv2/core/lv2.h>
+#include <lv2/ui/ui.h>
+#include <serd/serd.h>
+#include <sord/sord.h>
+#include <zix/tree.h>
+
 #include <math.h>
 #include <stdarg.h>
 #include <stdbool.h>
@@ -212,8 +212,8 @@ lilv_plugin_load(LilvPlugin* plugin)
   // Load and parse dynamic manifest data, if this is a library
   if (plugin->dynmanifest) {
     typedef int (*GetDataFunc)(
-      LV2_Dyn_Manifest_Handle handle, FILE * fp, const char* uri);
-    GetDataFunc get_data_func = (GetDataFunc)lilv_dlfunc(
+      LV2_Dyn_Manifest_Handle handle, FILE* fp, const char* uri);
+    GetDataFunc get_data_func = (GetDataFunc)dylib_func(
       plugin->dynmanifest->lib, "lv2_dyn_manifest_get_data");
     if (get_data_func) {
       const SordNode* bundle = plugin->dynmanifest->bundle->node;
@@ -489,7 +489,7 @@ lilv_plugin_get_name(const LilvPlugin* plugin)
 
   LilvNode* ret = NULL;
   if (results) {
-    LilvNode* val = lilv_nodes_get_first(results);
+    const LilvNode* val = lilv_nodes_get_first(results);
     if (lilv_node_is_string(val)) {
       ret = lilv_node_duplicate(val);
     }
@@ -588,7 +588,7 @@ lilv_plugin_get_num_ports_of_class_va(
 
   // Check each port against every type
   for (unsigned i = 0; i < plugin->num_ports; ++i) {
-    LilvPort* port = plugin->ports[i];
+    const LilvPort* port = plugin->ports[i];
     if (port && lilv_port_is_a(plugin, port, class_1)) {
       bool matches = true;
       for (size_t j = 0; j < n_classes; ++j) {
@@ -997,7 +997,7 @@ lilv_plugin_get_related(const LilvPlugin* plugin, const LilvNode* type)
 
   LilvNodes* matches = lilv_nodes_new();
   LILV_FOREACH (nodes, i, related) {
-    LilvNode* node = (LilvNode*)lilv_collection_get((ZixTree*)related, i);
+    const LilvNode* node = (LilvNode*)lilv_collection_get((ZixTree*)related, i);
     if (lilv_world_ask_internal(
           world, node->node, world->uris.rdf_a, type->node)) {
       zix_tree_insert(
@@ -1028,7 +1028,7 @@ new_lv2_env(const SerdNode* base)
 }
 
 static void
-maybe_write_prefixes(SerdWriter* writer, SerdEnv* env, FILE* file)
+maybe_write_prefixes(SerdWriter* writer, const SerdEnv* env, FILE* file)
 {
   fseek(file, 0, SEEK_END);
   if (ftell(file) == 0) {
