@@ -3,23 +3,22 @@
 
 #include "lilv_internal.h"
 
-#include "lilv/lilv.h"
-#include "serd/serd.h"
-#include "sord/sord.h"
-#include "sratom/sratom.h"
-#include "zix/allocator.h"
-#include "zix/filesystem.h"
-#include "zix/path.h"
-#include "zix/status.h"
-#include "zix/string_view.h"
-#include "zix/tree.h"
-
-#include "lv2/atom/atom.h"
-#include "lv2/atom/forge.h"
-#include "lv2/core/lv2.h"
-#include "lv2/presets/presets.h"
-#include "lv2/state/state.h"
-#include "lv2/urid/urid.h"
+#include <lilv/lilv.h>
+#include <lv2/atom/atom.h>
+#include <lv2/atom/forge.h>
+#include <lv2/core/lv2.h>
+#include <lv2/presets/presets.h>
+#include <lv2/state/state.h>
+#include <lv2/urid/urid.h>
+#include <serd/serd.h>
+#include <sord/sord.h>
+#include <sratom/sratom.h>
+#include <zix/allocator.h>
+#include <zix/filesystem.h>
+#include <zix/path.h>
+#include <zix/status.h>
+#include <zix/string_view.h>
+#include <zix/tree.h>
 
 #include <assert.h>
 #include <errno.h>
@@ -153,13 +152,13 @@ lilv_state_rel2abs(const LilvState* state, const char* path)
 }
 
 static void
-append_property(LilvState*     state,
-                PropertyArray* array,
-                uint32_t       key,
-                const void*    value,
-                size_t         size,
-                uint32_t       type,
-                uint32_t       flags)
+append_property(const LilvState* state,
+                PropertyArray*   array,
+                uint32_t         key,
+                const void*      value,
+                size_t           size,
+                uint32_t         type,
+                uint32_t         flags)
 {
   array->props =
     (Property*)realloc(array->props, (++array->n) * sizeof(Property));
@@ -257,10 +256,10 @@ lilv_state_has_path(const char* path, const void* state)
 static char*
 make_path(LV2_State_Make_Path_Handle handle, const char* path)
 {
-  LilvState* state = (LilvState*)handle;
-  zix_create_directories(NULL, state->dir);
-
-  return zix_path_join(NULL, state->dir, path);
+  const LilvState* state = (const LilvState*)handle;
+  return !zix_create_directories(NULL, state->dir)
+           ? zix_path_join(NULL, state->dir, path)
+           : NULL;
 }
 
 static bool
@@ -269,7 +268,7 @@ path_is_child(const char* path, const char* dir)
   if (path && dir) {
     const size_t path_len = strlen(path);
     const size_t dir_len  = strlen(dir);
-    return dir && path_len >= dir_len && !strncmp(path, dir, dir_len);
+    return path_len >= dir_len && !strncmp(path, dir, dir_len);
   }
   return false;
 }
@@ -293,7 +292,7 @@ abstract_path(LV2_State_Map_Path_Handle handle, const char* abs_path)
 
   if (!zix_tree_find(state->abs2rel, &key, &iter)) {
     // Already mapped path in a previous call
-    PathMap* pm = (PathMap*)zix_tree_get(iter);
+    const PathMap* pm = (const PathMap*)zix_tree_get(iter);
     zix_free(NULL, real_path);
     return lilv_strdup(pm->rel);
   }
@@ -353,8 +352,8 @@ abstract_path(LV2_State_Map_Path_Handle handle, const char* abs_path)
 static char*
 absolute_path(LV2_State_Map_Path_Handle handle, const char* state_path)
 {
-  LilvState* state = (LilvState*)handle;
-  char*      path  = NULL;
+  const LilvState* state = (const LilvState*)handle;
+  char*            path  = NULL;
   if (zix_path_is_absolute(state_path)) {
     // Absolute path, return identical path
     path = lilv_strdup(state_path);
@@ -670,12 +669,13 @@ new_state_from_model(LilvWorld*      world,
       chunk.len = 0;
       sratom_read(sratom, &forge, world->world, model, value);
       const LV2_Atom* atom = (const LV2_Atom*)chunk.buf;
-
-      append_port_value(state,
-                        (const char*)sord_node_get_string(symbol),
-                        LV2_ATOM_BODY_CONST(atom),
-                        atom->size,
-                        atom->type);
+      if (atom) {
+        append_port_value(state,
+                          (const char*)sord_node_get_string(symbol),
+                          LV2_ATOM_BODY_CONST(atom),
+                          atom->size,
+                          atom->type);
+      }
 
       if (label) {
         lilv_state_set_label(state, (const char*)sord_node_get_string(label));
@@ -705,6 +705,9 @@ new_state_from_model(LilvWorld*      world,
       const LV2_Atom* atom  = (const LV2_Atom*)chunk.buf;
       uint32_t        flags = LV2_STATE_IS_POD | LV2_STATE_IS_PORTABLE;
       Property        prop  = {NULL, 0, 0, 0, flags};
+      if (!atom) {
+        continue;
+      }
 
       prop.key   = map->map(map->handle, key);
       prop.type  = atom->type;
@@ -777,19 +780,20 @@ lilv_state_new_from_file(LilvWorld*      world,
 
   serd_reader_read_file(reader, (const uint8_t*)node.buf);
 
-  SordNode* subject_node =
+  const SordNode* subject_node =
     (subject) ? subject->node
               : sord_node_from_serd_node(world->world, env, &node, NULL, NULL);
 
-  const ZixStringView dirname   = zix_path_parent_path(path);
-  char* const         real_path = zix_canonical_path(NULL, dirname.data);
-  char* const         dir_path  = zix_path_join(NULL, real_path, NULL);
+  char* const dirname = zix_string_view_copy(NULL, zix_path_parent_path(path));
+  char* const real_path = zix_canonical_path(NULL, dirname);
+  char* const dir_path  = zix_path_join(NULL, real_path, NULL);
 
   LilvState* const state =
     new_state_from_model(world, map, model, subject_node, dir_path);
 
   zix_free(NULL, dir_path);
   zix_free(NULL, real_path);
+  zix_free(NULL, dirname);
 
   serd_node_free(&node);
   zix_free(NULL, abs_path);
@@ -909,7 +913,7 @@ remove_manifest_entry(SordWorld* world, SordModel* model, const char* subject)
   SordNode* s = sord_new_uri(world, USTR(subject));
   SordIter* i = sord_search(model, s, NULL, NULL, NULL);
   while (!sord_iter_end(i)) {
-    sord_erase(model, i);
+    (void)sord_erase(model, i);
   }
   sord_iter_free(i);
   sord_node_free(world, s);
@@ -1147,7 +1151,7 @@ lilv_state_write(LilvWorld*       world,
     serd_writer_write_statement(writer, 0, NULL, &subject, &p, &o, NULL, NULL);
   }
 
-  SerdEnv*        env  = serd_writer_get_env(writer);
+  const SerdEnv*  env  = serd_writer_get_env(writer);
   const SerdNode* base = serd_env_get_base_uri(env, NULL);
 
   Sratom* sratom = sratom_new(map);
@@ -1165,7 +1169,7 @@ lilv_state_write(LilvWorld*       world,
   // Write port values
   sratom_set_pretty_numbers(sratom, true); // Use pretty numbers
   for (uint32_t i = 0; i < state->n_values; ++i) {
-    PortValue* const value = &state->values[i];
+    const PortValue* const value = &state->values[i];
 
     const SerdNode port =
       serd_node_from_string(SERD_BLANK, USTR(value->symbol));
@@ -1234,7 +1238,7 @@ lilv_state_make_links(const LilvState* state, const char* dir)
 
       if (!strcmp(dir, link_dir)) {
         // Link directory is save directory, make link at exact path
-        remove(pat);
+        (void)zix_remove(pat);
         maybe_symlink(pm->abs, pat);
       } else {
         // Make a link in the link directory to external file
@@ -1398,7 +1402,7 @@ lilv_state_delete(LilvWorld* world, const LilvState* state)
   }
 
   if (state->uri) {
-    SordNode* file =
+    const SordNode* file =
       sord_get(model, state->uri->node, world->uris.rdfs_seeAlso, NULL, NULL);
     if (file) {
       // Remove state file
@@ -1471,7 +1475,7 @@ lilv_state_delete(LilvWorld* world, const LilvState* state)
 }
 
 static void
-free_property_array(LilvState* state, PropertyArray* array)
+free_property_array(const LilvState* state, PropertyArray* array)
 {
   for (uint32_t i = 0; i < array->n; ++i) {
     Property* prop = &array->props[i];
@@ -1517,8 +1521,8 @@ lilv_state_equals(const LilvState* a, const LilvState* b)
   }
 
   for (uint32_t i = 0; i < a->n_values; ++i) {
-    PortValue* const av = &a->values[i];
-    PortValue* const bv = &b->values[i];
+    const PortValue* const av = &a->values[i];
+    const PortValue* const bv = &b->values[i];
     if (av->atom->size != bv->atom->size || av->atom->type != bv->atom->type ||
         !!strcmp(av->symbol, bv->symbol) ||
         !!memcmp(av->atom + 1, bv->atom + 1, av->atom->size)) {
@@ -1527,8 +1531,8 @@ lilv_state_equals(const LilvState* a, const LilvState* b)
   }
 
   for (uint32_t i = 0; i < a->props.n; ++i) {
-    Property* const ap = &a->props.props[i];
-    Property* const bp = &b->props.props[i];
+    const Property* const ap = &a->props.props[i];
+    const Property* const bp = &b->props.props[i];
     if (ap->key != bp->key || ap->type != bp->type || ap->flags != bp->flags) {
       return false;
     }
