@@ -1,23 +1,25 @@
-// Copyright 2007-2019 David Robillard <d@drobilla.net>
+// Copyright 2007-2024 David Robillard <d@drobilla.net>
 // SPDX-License-Identifier: ISC
 
-#include "lilv_config.h" // IWYU pragma: keep
+#include "lilv_config.h"
 #include "lilv_internal.h"
 
-#include "lilv/lilv.h"
-#include "serd/serd.h"
-#include "sord/sord.h"
-#include "zix/filesystem.h"
-#include "zix/tree.h"
-
-#include "lv2/core/lv2.h"
-#include "lv2/presets/presets.h"
-
 #ifdef LILV_DYN_MANIFEST
-#  include "lv2/dynmanifest/dynmanifest.h"
+#  include "dylib.h"
+#  include <lv2/dynmanifest/dynmanifest.h>
 #endif
 
+#include <lilv/lilv.h>
+#include <lv2/core/lv2.h>
+#include <lv2/presets/presets.h>
+#include <serd/serd.h>
+#include <sord/sord.h>
+#include <zix/environment.h>
+#include <zix/filesystem.h>
+#include <zix/tree.h>
+
 #include <assert.h>
+#include <limits.h>
 #include <stdbool.h>
 #include <stdint.h>
 #include <stdio.h>
@@ -264,7 +266,7 @@ lilv_world_get(LilvWorld*      world,
   SordNode* snode = sord_get(world->model,
                              subject ? subject->node : NULL,
                              predicate ? predicate->node : NULL,
-                             object ? object->node : NULL,
+                             object->node,
                              NULL);
   LilvNode* lnode = lilv_node_new_from_node(world, snode);
   sord_node_free(world->world, snode);
@@ -382,7 +384,7 @@ lilv_collection_find_by_uri(const ZixTree* seq, const LilvNode* uri)
   ZixTreeIter* i = NULL;
   if (lilv_node_is_uri(uri)) {
     struct LilvHeader key = {NULL, (LilvNode*)uri};
-    zix_tree_find(seq, &key, &i);
+    (void)zix_tree_find(seq, &key, &i);
   }
   return i;
 }
@@ -391,7 +393,7 @@ lilv_collection_find_by_uri(const ZixTree* seq, const LilvNode* uri)
 struct LilvHeader*
 lilv_collection_get_by_uri(const ZixTree* seq, const LilvNode* uri)
 {
-  ZixTreeIter* const i = lilv_collection_find_by_uri(seq, uri);
+  const ZixTreeIter* const i = lilv_collection_find_by_uri(seq, uri);
 
   return i ? (struct LilvHeader*)zix_tree_get(i) : NULL;
 }
@@ -551,8 +553,8 @@ lilv_world_load_dyn_manifest(LilvWorld*      world,
     }
 
     // Open library
-    dlerror();
-    void* lib = dlopen(lib_path, RTLD_LAZY);
+    dylib_error();
+    void* lib = dylib_open(lib_path, DYLIB_LAZY);
     if (!lib) {
       LILV_ERRORF(
         "Failed to open dynmanifest library `%s' (%s)\n", lib_path, dlerror());
@@ -564,11 +566,11 @@ lilv_world_load_dyn_manifest(LilvWorld*      world,
     // Open dynamic manifest
     typedef int (*OpenFunc)(LV2_Dyn_Manifest_Handle*,
                             const LV2_Feature* const*);
-    OpenFunc dmopen = (OpenFunc)lilv_dlfunc(lib, "lv2_dyn_manifest_open");
+    OpenFunc dmopen = (OpenFunc)dylib_func(lib, "lv2_dyn_manifest_open");
     if (!dmopen || dmopen(&handle, &dman_features)) {
       LILV_ERRORF("No `lv2_dyn_manifest_open' in `%s'\n", lib_path);
       sord_iter_free(binaries);
-      dlclose(lib);
+      dylib_close(lib);
       lilv_free(lib_path);
       continue;
     }
@@ -576,11 +578,11 @@ lilv_world_load_dyn_manifest(LilvWorld*      world,
     // Get subjects (the data that would be in manifest.ttl)
     typedef int (*GetSubjectsFunc)(LV2_Dyn_Manifest_Handle, FILE*);
     GetSubjectsFunc get_subjects_func =
-      (GetSubjectsFunc)lilv_dlfunc(lib, "lv2_dyn_manifest_get_subjects");
+      (GetSubjectsFunc)dylib_func(lib, "lv2_dyn_manifest_get_subjects");
     if (!get_subjects_func) {
       LILV_ERRORF("No `lv2_dyn_manifest_get_subjects' in `%s'\n", lib_path);
       sord_iter_free(binaries);
-      dlclose(lib);
+      dylib_close(lib);
       lilv_free(lib_path);
       continue;
     }
@@ -647,12 +649,12 @@ lilv_dynmanifest_free(LilvDynManifest* dynmanifest)
 {
   typedef int (*CloseFunc)(LV2_Dyn_Manifest_Handle);
   CloseFunc close_func =
-    (CloseFunc)lilv_dlfunc(dynmanifest->lib, "lv2_dyn_manifest_close");
+    (CloseFunc)dylib_func(dynmanifest->lib, "lv2_dyn_manifest_close");
   if (close_func) {
     close_func(dynmanifest->handle);
   }
 
-  dlclose(dynmanifest->lib);
+  dylib_close(dynmanifest->lib);
   lilv_node_free(dynmanifest->bundle);
   free(dynmanifest);
 }
@@ -666,7 +668,7 @@ lilv_world_get_manifest_uri(LilvWorld* world, const LilvNode* bundle_uri)
   const char* const bundle_uri_string =
     (const char*)sord_node_get_string_counted(bundle_uri->node,
                                               &bundle_uri_length);
-  if (!bundle_uri_length) {
+  if (bundle_uri_length < 1U) {
     return NULL;
   }
 
@@ -688,10 +690,10 @@ load_plugin_model(LilvWorld*      world,
                   const LilvNode* plugin_uri)
 {
   // Create model and reader for loading into it
-  SordNode*   bundle_node = bundle_uri->node;
-  SordModel*  model       = sord_new(world->world, SORD_SPO | SORD_OPS, false);
-  SerdEnv*    env         = serd_env_new(sord_node_to_serd_node(bundle_node));
-  SerdReader* reader      = sord_new_reader(model, env, SERD_TURTLE, NULL);
+  const SordNode* bundle_node = bundle_uri->node;
+  SordModel*      model  = sord_new(world->world, SORD_SPO | SORD_OPS, false);
+  SerdEnv*        env    = serd_env_new(sord_node_to_serd_node(bundle_node));
+  SerdReader*     reader = sord_new_reader(model, env, SERD_TURTLE, NULL);
 
   // Load manifest
   LilvNode* manifest_uri = lilv_world_get_manifest_uri(world, bundle_uri);
@@ -723,7 +725,7 @@ load_plugin_model(LilvWorld*      world,
 }
 
 static LilvVersion
-get_version(LilvWorld* world, SordModel* model, const LilvNode* subject)
+get_version(const LilvWorld* world, SordModel* model, const LilvNode* subject)
 {
   const SordNode* minor_node =
     sord_get(model, subject->node, world->uris.lv2_minorVersion, NULL, NULL);
@@ -732,8 +734,14 @@ get_version(LilvWorld* world, SordModel* model, const LilvNode* subject)
 
   LilvVersion version = {0, 0};
   if (minor_node && micro_node) {
-    version.minor = atoi((const char*)sord_node_get_string(minor_node));
-    version.micro = atoi((const char*)sord_node_get_string(micro_node));
+    const char* const minor_str = (const char*)sord_node_get_string(minor_node);
+    const char* const micro_str = (const char*)sord_node_get_string(micro_node);
+    const long        minor     = strtol(minor_str, NULL, 10);
+    const long        micro     = strtol(micro_str, NULL, 10);
+    if (minor >= 0 && minor < INT_MAX && micro >= 0 && micro < INT_MAX) {
+      version.minor = (int)minor;
+      version.micro = (int)micro;
+    }
   }
 
   return version;
@@ -876,6 +884,7 @@ lilv_world_drop_graph(LilvWorld* world, const SordNode* graph)
   while (!sord_iter_end(i)) {
     const SerdStatus st = sord_erase(world->model, i);
     if (st) {
+      sord_iter_free(i);
       LILV_ERRORF("Error removing statement from <%s> (%s)\n",
                   sord_node_get_string(graph),
                   serd_strerror(st));
@@ -966,7 +975,7 @@ load_dir_entry(const char* dir, const char* name, void* data)
 static void
 lilv_world_load_directory(LilvWorld* world, const char* dir_path)
 {
-  char* path = lilv_expand(dir_path);
+  char* const path = zix_expand_environment_strings(NULL, dir_path);
   if (path) {
     zix_dir_for_each(path, world, load_dir_entry);
     free(path);
@@ -1014,7 +1023,8 @@ lilv_world_load_specifications(LilvWorld* world)
 {
   for (LilvSpec* spec = world->specs; spec; spec = spec->next) {
     LILV_FOREACH (nodes, f, spec->data_uris) {
-      LilvNode* file = (LilvNode*)lilv_collection_get(spec->data_uris, f);
+      const LilvNode* file =
+        (const LilvNode*)lilv_collection_get(spec->data_uris, f);
       lilv_world_load_graph(world, NULL, file);
     }
   }
