@@ -4,7 +4,8 @@
 #ifndef LILV_TEST_UTILS_H
 #define LILV_TEST_UTILS_H
 
-#include "lilv/lilv.h"
+#include <lilv/lilv.h>
+#include <zix/attributes.h>
 
 #define MANIFEST_PREFIXES \
   "\
@@ -80,7 +81,12 @@ void
 set_env(const char* name, const char* value);
 
 // Create a unique temporary directory
+ZIX_MALLOC_FUNC
 char*
 lilv_create_temporary_directory(const char* pattern);
 
+// Return a new string that is a concatenation of two given strings
+char*
+string_concat(const char* head, const char* tail);
+
 #endif // LILV_TEST_UTILS_H
