@@ -5,7 +5,7 @@
 
 #include "lilv_test_utils.h"
 
-#include "lilv/lilv.h"
+#include <lilv/lilv.h>
 
 #include <assert.h>
 
@@ -14,8 +14,8 @@ static const char* const plugin_ttl = ":plug a lv2:Plugin .\n";
 int
 main(void)
 {
-  LilvTestEnv* const env   = lilv_test_env_new();
-  LilvWorld* const   world = env->world;
+  LilvTestEnv* const     env   = lilv_test_env_new();
+  const LilvWorld* const world = env->world;
 
   if (create_bundle(env, "no_verify.lv2", SIMPLE_MANIFEST_TTL, plugin_ttl)) {
     return 1;
