@@ -6,21 +6,14 @@
 #include "lilv_test_uri_map.h"
 #include "lilv_test_utils.h"
 
-#include "lilv/lilv.h"
-#include "lv2/core/lv2.h"
-#include "lv2/state/state.h"
-#include "lv2/urid/urid.h"
-#include "serd/serd.h"
-#include "zix/allocator.h"
-#include "zix/filesystem.h"
-#include "zix/path.h"
-
-#ifdef _WIN32
-#  include <direct.h>
-#  define mkdir(path, flags) _mkdir(path)
-#else
-#  include <sys/stat.h>
-#endif
+#include <lilv/lilv.h>
+#include <lv2/core/lv2.h>
+#include <lv2/state/state.h>
+#include <lv2/urid/urid.h>
+#include <serd/serd.h>
+#include <zix/allocator.h>
+#include <zix/filesystem.h>
+#include <zix/path.h>
 
 #include <assert.h>
 #include <stdbool.h>
@@ -128,10 +121,10 @@ create_test_directories(void)
   assert(dirs.copy);
   assert(dirs.link);
 
-  assert(!mkdir(dirs.shared, 0700));
-  assert(!mkdir(dirs.scratch, 0700));
-  assert(!mkdir(dirs.copy, 0700));
-  assert(!mkdir(dirs.link, 0700));
+  assert(!zix_create_directory(dirs.shared));
+  assert(!zix_create_directory(dirs.scratch));
+  assert(!zix_create_directory(dirs.copy));
+  assert(!zix_create_directory(dirs.link));
 
   free(top);
 
@@ -235,7 +228,7 @@ set_port_value(const char* port_symbol,
 static char*
 make_scratch_path(LV2_State_Make_Path_Handle handle, const char* path)
 {
-  TestDirectories* dirs = (TestDirectories*)handle;
+  const TestDirectories* dirs = (TestDirectories*)handle;
 
   return zix_path_join(NULL, dirs->scratch, path);
 }
@@ -751,7 +744,7 @@ test_multi_save(void)
 
   lilv_instance_free(instance);
   zix_dir_for_each(bundle_1_path, NULL, remove_file);
-  zix_remove(bundle_1_path);
+  assert(!zix_remove(bundle_1_path));
   cleanup_test_directories(dirs);
 
   free(state_path);
@@ -859,9 +852,9 @@ test_files_round_trip(void)
   zix_dir_for_each(bundle_1_1_path, NULL, remove_file);
   zix_dir_for_each(bundle_1_2_path, NULL, remove_file);
   zix_dir_for_each(bundle_2_path, NULL, remove_file);
-  zix_remove(bundle_1_1_path);
-  zix_remove(bundle_1_2_path);
-  zix_remove(bundle_2_path);
+  assert(!zix_remove(bundle_1_1_path));
+  assert(!zix_remove(bundle_1_2_path));
+  assert(!zix_remove(bundle_2_path));
   cleanup_test_directories(dirs);
 
   lilv_state_free(state_2_loaded);
@@ -1010,12 +1003,12 @@ test_bad_subject(void)
   TestContext* const ctx    = test_context_new();
   LilvNode* const    string = lilv_new_string(ctx->env->world, "Not a URI");
 
-  LilvState* const file_state = lilv_state_new_from_file(
+  const LilvState* const file_state = lilv_state_new_from_file(
     ctx->env->world, &ctx->map, string, "/I/do/not/matter");
 
   assert(!file_state);
 
-  LilvState* const world_state =
+  const LilvState* const world_state =
     lilv_state_new_from_world(ctx->env->world, &ctx->map, string);
 
   assert(!world_state);
@@ -1027,8 +1020,8 @@ test_bad_subject(void)
 static void
 test_missing_path(void)
 {
-  TestContext* const ctx   = test_context_new();
-  LilvState* const   state = lilv_state_new_from_file(
+  TestContext* const     ctx   = test_context_new();
+  const LilvState* const state = lilv_state_new_from_file(
     ctx->env->world, &ctx->map, NULL, "/does/not/exist");
 
   assert(!state);
