@@ -5,9 +5,9 @@
 
 #include "lilv_test_utils.h"
 
-#include "lilv/lilv.h"
-#include "zix/filesystem.h"
-#include "zix/path.h"
+#include <lilv/lilv.h>
+#include <zix/filesystem.h>
+#include <zix/path.h>
 
 #include <assert.h>
 #include <stdio.h>
@@ -22,6 +22,8 @@ main(void)
 
   FILE* const fa = fopen(a_path, "w");
   FILE* const fb = fopen(b_path, "w");
+  assert(fa);
+  assert(fb);
   fprintf(fa, "AA\n");
   fprintf(fb, "AB\n");
   fclose(fb);
