@@ -1,15 +1,14 @@
 // Copyright 2012-2019 David Robillard <d@drobilla.net>
 // SPDX-License-Identifier: ISC
 
-#include "lilv/lilv.h"
-#include "lv2/atom/atom.h"
-#include "lv2/core/lv2.h"
-#include "lv2/urid/urid.h"
-
 #include "bench.h"
-#include "lilv_config.h"
 #include "uri_table.h"
 
+#include <lilv/lilv.h>
+#include <lv2/atom/atom.h>
+#include <lv2/core/lv2.h>
+#include <lv2/urid/urid.h>
+
 #include <math.h>
 #include <stdbool.h>
 #include <stdint.h>
@@ -46,13 +45,13 @@ print_usage(void)
   printf("Usage: lv2bench [OPTIONS] [PLUGIN_URI]\n");
   printf("\n");
   printf("  -V, --version  Display version information and exit\n");
-  printf("  -b BLOCK_SIZE  Specify block size, in audio frames.\n");
-  printf("  -f, --full     Full plottable output.\n");
-  printf("  -h, --help     Display this help and exit.\n");
+  printf("  -b BLOCK_SIZE  Specify block size, in audio frames\n");
+  printf("  -f, --full     Full plottable output\n");
+  printf("  -h, --help     Display this help and exit\n");
   printf("  -n FRAMES      Total number of audio frames to process\n");
 }
 
-static double
+static int
 bench(const LilvPlugin* p, uint32_t sample_count, uint32_t block_size)
 {
   URITable uri_table;
@@ -65,13 +64,14 @@ bench(const LilvPlugin* p, uint32_t sample_count, uint32_t block_size)
   const LV2_Feature* features[]    = {&map_feature, &unmap_feature, NULL};
 
   float* const buf = (float*)calloc(block_size * 2UL, sizeof(float));
-  float* const in  = buf;
-  float* const out = buf + block_size;
   if (!buf) {
     fprintf(stderr, "Out of memory\n");
-    return 0.0;
+    return 1;
   }
 
+  float* const in  = buf;
+  float* const out = buf + block_size;
+
   const size_t atom_capacity = 1024;
 
   LV2_Atom_Sequence seq_in = {{sizeof(LV2_Atom_Sequence_Body),
@@ -81,8 +81,8 @@ bench(const LilvPlugin* p, uint32_t sample_count, uint32_t block_size)
   LV2_Atom_Sequence* seq_out =
     (LV2_Atom_Sequence*)malloc(sizeof(LV2_Atom_Sequence) + atom_capacity);
 
-  const char* uri      = lilv_node_as_string(lilv_plugin_get_uri(p));
-  LilvNodes*  required = lilv_plugin_get_required_features(p);
+  const char*      uri      = lilv_node_as_string(lilv_plugin_get_uri(p));
+  const LilvNodes* required = lilv_plugin_get_required_features(p);
   LILV_FOREACH (nodes, i, required) {
     const LilvNode* feature = lilv_nodes_get(required, i);
     if (!lilv_node_equals(feature, urid_map)) {
@@ -93,7 +93,7 @@ bench(const LilvPlugin* p, uint32_t sample_count, uint32_t block_size)
       free(seq_out);
       free(buf);
       uri_table_destroy(&uri_table);
-      return 0.0;
+      return 1;
     }
   }
 
@@ -105,7 +105,7 @@ bench(const LilvPlugin* p, uint32_t sample_count, uint32_t block_size)
     free(seq_out);
     free(buf);
     uri_table_destroy(&uri_table);
-    return 0.0;
+    return 1;
   }
 
   const uint32_t n_ports  = lilv_plugin_get_num_ports(p);
@@ -114,7 +114,8 @@ bench(const LilvPlugin* p, uint32_t sample_count, uint32_t block_size)
   float* const   controls = (float*)calloc(n_ports, sizeof(float));
   lilv_plugin_get_port_ranges_float(p, mins, maxes, controls);
 
-  for (uint32_t index = 0; index < n_ports; ++index) {
+  bool skip_plugin = false;
+  for (uint32_t index = 0; !skip_plugin && index < n_ports; ++index) {
     const LilvPort* port = lilv_plugin_get_port_by_index(p, index);
     if (lilv_port_is_a(p, port, lv2_ControlPort)) {
       if (isnan(controls[index])) {
@@ -138,12 +139,7 @@ bench(const LilvPlugin* p, uint32_t sample_count, uint32_t block_size)
                 "<%s> port %u neither input nor output, skipping\n",
                 uri,
                 index);
-        lilv_instance_free(instance);
-        free(seq_out);
-        free(buf);
-        free(controls);
-        uri_table_destroy(&uri_table);
-        return 0.0;
+        skip_plugin = true;
       }
     } else if (lilv_port_is_a(p, port, atom_AtomPort)) {
       if (lilv_port_is_a(p, port, lv2_InputPort)) {
@@ -153,44 +149,42 @@ bench(const LilvPlugin* p, uint32_t sample_count, uint32_t block_size)
       }
     } else {
       fprintf(stderr, "<%s> port %u has unknown type, skipping\n", uri, index);
-      lilv_instance_free(instance);
-      free(seq_out);
-      free(buf);
-      free(controls);
-      uri_table_destroy(&uri_table);
-      return 0.0;
+      skip_plugin = true;
     }
   }
 
-  lilv_instance_activate(instance);
+  if (!skip_plugin) {
+    lilv_instance_activate(instance);
 
-  struct timespec ts = bench_start();
-  for (uint32_t i = 0; i < (sample_count / block_size); ++i) {
-    seq_in.atom.size   = sizeof(LV2_Atom_Sequence_Body);
-    seq_in.atom.type   = uri_table_map(&uri_table, LV2_ATOM__Sequence);
-    seq_out->atom.size = atom_capacity;
-    seq_out->atom.type = uri_table_map(&uri_table, LV2_ATOM__Chunk);
+    struct timespec ts = bench_start();
 
-    lilv_instance_run(instance, block_size);
+    for (uint32_t i = 0; i < (sample_count / block_size); ++i) {
+      seq_in.atom.size   = sizeof(LV2_Atom_Sequence_Body);
+      seq_in.atom.type   = uri_table_map(&uri_table, LV2_ATOM__Sequence);
+      seq_out->atom.size = atom_capacity;
+      seq_out->atom.type = uri_table_map(&uri_table, LV2_ATOM__Chunk);
+
+      lilv_instance_run(instance, block_size);
+    }
+
+    const double elapsed = bench_end(&ts);
+
+    if (full_output) {
+      printf("%u %u ", block_size, sample_count);
+    }
+    printf("%lf %s\n", elapsed, uri);
+
+    lilv_instance_deactivate(instance);
   }
-  const double elapsed = bench_end(&ts);
 
-  lilv_instance_deactivate(instance);
-  lilv_instance_free(instance);
   free(controls);
   free(maxes);
   free(mins);
+  lilv_instance_free(instance);
   free(seq_out);
-
-  uri_table_destroy(&uri_table);
-
-  if (full_output) {
-    printf("%u %u ", block_size, sample_count);
-  }
-  printf("%lf %s\n", elapsed, uri);
-
   free(buf);
-  return elapsed;
+  uri_table_destroy(&uri_table);
+  return 0;
 }
 
 int
@@ -214,9 +208,15 @@ main(int argc, char** argv)
     if (!strcmp(argv[a], "-f")) {
       full_output = true;
     } else if (!strcmp(argv[a], "-n") && (a + 1 < argc)) {
-      sample_count = atoi(argv[++a]);
+      const long l = strtol(argv[++a], NULL, 10);
+      if (l > 0 && l < (1L << 28L)) {
+        sample_count = (uint32_t)l;
+      }
     } else if (!strcmp(argv[a], "-b") && (a + 1 < argc)) {
-      block_size = atoi(argv[++a]);
+      const long l = strtol(argv[++a], NULL, 10);
+      if (l > 0 && l < 16384) {
+        block_size = (uint32_t)l;
+      }
     } else if (argv[a][0] != '-') {
       break;
     } else {
